"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceAssetsWithImports = void 0;
const core_1 = require("@babel/core");
const path = require("path");
const absolutePathToRelative_1 = require("./absolutePathToRelative");
const parseStringWithUrl_1 = require("./parseStringWithUrl");
/**
 * Replaces assets used in styles with imports and template literals.
 *
 * @example
 * "['.foo { background-image: url(image.png) }"
 * // to
 * import _asset from 'image.png'
 * `['.foo { background-image: url(${_asset}) }`
 */
function replaceAssetsWithImports(projectRoot, filename, programPath, pathToUpdate) {
    const assetIdentifiers = new Map();
    function getAssetIdentifier(assetPath) {
        if (!assetIdentifiers.has(assetPath)) {
            assetIdentifiers.set(assetPath, programPath.scope.generateUidIdentifier('asset'));
        }
        return assetIdentifiers.get(assetPath);
    }
    (0, core_1.traverse)(pathToUpdate.node, {
        StringLiteral(literalPath) {
            const value = literalPath.node.value;
            if (value.indexOf('url(') === -1) {
                return;
            }
            const result = (0, parseStringWithUrl_1.parseStringWithUrl)(value);
            const assetIdentifier = getAssetIdentifier(result.url);
            const templateLiteral = core_1.types.templateLiteral([core_1.types.templateElement({ raw: result.prefix }, false), core_1.types.templateElement({ raw: result.suffix }, true)], [assetIdentifier]);
            literalPath.replaceWith(templateLiteral);
        },
    }, programPath.scope, programPath);
    for (const [importPath, identifier] of assetIdentifiers.entries()) {
        const relativePath = (0, absolutePathToRelative_1.absolutePathToRelative)(path, projectRoot, filename, importPath);
        programPath.unshiftContainer('body', core_1.types.importDeclaration([core_1.types.importDefaultSpecifier(identifier)], core_1.types.stringLiteral(relativePath)));
    }
}
exports.replaceAssetsWithImports = replaceAssetsWithImports;
//# sourceMappingURL=replaceAssetsWithImports.js.map